REM  2020-06-27
REM  Batch file to build libtcd and tide with DJGPP.
REM  Works on FreeDOS with FreeCOM shell.  LFN is required.

REM  This program is distributed in the hope that it will be useful, but
REM  WITHOUT ANY WARRANTY; without even the implied warranty of
REM  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the LICENSE
REM  file (GPLv3) for details.

REM  Non-built dependencies:
REM  Using libpng and zlib that are provided with DJGPP.
REM  ftp://ftp.delorie.com/pub/djgpp/current/v2tk/

REM  Location of the FunkyBuilds DOS directory.
SET FUNK=c:\xtide\funkybuilds\dos

REM  Source tarballs must be in this directory.  One per package, please.
SET RELSRC=c:\xtide\src

REM  Installation prefix.
SET DEST=c:\xtide

REM  Empty scratch directory to build in.
SET BUILDDIR=c:\tmp

REM  Strange bug:  wildcards don't work in directory names with CD.
REM  Provide full names here as a workaround.
REM  (The full name, in turn, doesn't work with DELTREE.)
SET LIBTCD=libtcd-2.2.7
SET XTIDE=xtide-2.15.3


REM  libtcd

CD %BUILDDIR%
%FUNK%\xz.exe -dc %RELSRC%\libtcd*.xz | tar xvf -
CD %LIBTCD%
COPY %FUNK%\tcd.h .
SET CFLAGS=-DHAVE_UNISTD_H=1 -I. -Os
gcc %CFLAGS% -c bit_pack.c -o bit_pack.o
gcc %CFLAGS% -c tide_db.c -o tide_db.o
ar scru libtcd.a bit_pack.o tide_db.o

MKDIR %DEST%\LIB
MKDIR %DEST%\INCLUDE
MKDIR %DEST%\SHARE
MKDIR %DEST%\SHARE\LIBTCD

COPY tcd.h %DEST%\INCLUDE
COPY libtcd.a %DEST%\LIB
COPY libtcd.html %DEST%\SHARE\LIBTCD

CD ..
DELTREE /Y libtcd*.*


REM  tide
REM  Not going to bother installing libxtide.

%FUNK%\xz.exe -dc %RELSRC%\xtide*.xz | tar xvf -
CD %XTIDE%
COPY %FUNK%\autoconf-defines.h libxtide
REM  There's a 125 character limit.  Arguments continue in tidegpp.txt.
REM  The quoting protocol is particular to DJGPP.
gpp -DPACKAGE_STRING='"XTide 2.15.3 DOS"' -I%DEST%\INCLUDE -L%DEST%\LIB @%FUNK%\tidegpp.txt

MKDIR %DEST%\BIN
MKDIR %DEST%\SHARE\MAN
MKDIR %DEST%\SHARE\MAN\MAN1

COPY tide.exe %DEST%\BIN
COPY tide.1 %DEST%\SHARE\MAN\MAN1

CD ..
DELTREE /Y xtide*.*
