#!/bin/bash
# 2020-06-28
# Big bang build of all XTide-related stuff for Ubuntu 20.04 "Focal Fossa"
# Does not install the harmonics tcd or WVS files.
# Does not handle spaces in paths.
# See README.txt about apt-get dependencies and xttpd.

# BE CAREFUL with this.  It's fast and dangerous, with an rm -rf and
# wildcards and path names that aren't quoted.

# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the LICENSE file (GPLv3) for
# details.

set -e

# Source tarballs must be in this directory.  One per package, please; the
# x.y.z-rn versions don't sort like you would hope.
RELSRC=${HOME}/xtide/src

# Installation prefix.
DEST=${HOME}/xtide

# Empty scratch directory to build in.
BUILDDIR=${HOME}/tmp

# Specify number of CPU cores.
JFLAG="-j 8"

# User and group for xttpd.
XTTCFG="--with-xttpd-user=`id -nu 1000` --with-xttpd-group=`id -ng 1000`"

# Funky GCC options.
# Can add libc FORTIFY.  Can add Address Sanitizer, but not for tideEditor.
# Qt sets off alarms.
XCPP="-I${DEST}/include -I/usr/include/postgresql -I/usr/include/x86_64-linux-gnu/qt5"
XC1="-flto -fuse-linker-plugin -O3"
XLD1="-L${DEST}/lib -L/usr/lib/x86_64-linux-gnu -Wl,-rpath,${DEST}/lib,--disable-new-dtags"

# Standard_build is standard.
# arg1: package name
# arg2: extra configure flags
function standard_build {
  echo BEGIN standard_build $1
  SRCFILE=`ls -d ${RELSRC}/${1}*.tar.* 2>/dev/null | tail -1`
  if [ -n "${SRCFILE}" ]; then
    cd ${BUILDDIR}
    tar xf ${SRCFILE}
    cd ${1}*
    ./configure --disable-dependency-tracking --prefix="${DEST}" $2 \
      CPPFLAGS="${XCPP}" CFLAGS="${XC1}" CXXFLAGS="${XC1}" LDFLAGS="${XLD1}" \
      AR="gcc-ar" RANLIB="gcc-ranlib" NM="gcc-nm"
    make ${JFLAG}
    make install
#    if [ "$1" = "xtide" ]; then
#      sudo make install-systemd
#      sudo make enable-systemd
#    fi
    cd ..
    rm -rf ${1}*
  else
    echo "Source file not found in ${RELSRC}.  Skipping it."
  fi
  echo END standard_build $1
}

standard_build libXaw3dXft "--enable-internationalization --enable-multiplane-bitmaps --enable-gray-stipples --enable-arrow-scrollbars"
standard_build libdstr
standard_build libtcd
standard_build xtide "${XTTCFG} --enable-systemd"
standard_build congen
standard_build harmbase2
standard_build harmgen
standard_build tcd-utils

XCPP="-fPIC ${XCPP}"
XC1="-fPIC ${XC1}"
standard_build tideeditor
